@@ -1,4 +1,4 @@
-;;; debian-changelog-mode.el --- major mode for Debian changelog files.
+;;; debian-changelog-mode.el --- major mode for Debian changelog files -*- lexical-binding: t -*-
 
 ;; Copyright (C) 1996 Ian Jackson
 ;; Copyright (C) 1997 Klee Dienes
@@ -366,6 +366,7 @@
 
 ;;; Code:
 (require 'debian-bug)  ;; for debian-bug-build-bug-menu
+(require 'dpkg-dev-common-utils)
 
 (defgroup debian-changelog nil "Debian changelog maintenance"
   :group 'tools
@@ -1065,7 +1066,7 @@ If file is empty, create initial entry."
     (if (debian-changelog-experimental-p)
         (insert pkg-name " (" version ") experimental; urgency=medium\n\n  * ")
       (insert pkg-name " (" version ") " (car debian-changelog-allowed-distributions) "; urgency=medium\n\n  * "))
-    (run-hooks 'debian-changelog-add-version-hook)
+    (run-mode-hooks 'debian-changelog-add-version-hook)
     (save-excursion (insert "\n\n --\n\n"))))
 
 (defun debian-changelog-experimental-p ()
@@ -1590,6 +1591,7 @@ interface to set it, or simply set the variable
    (debian-changelog-highlight-mouse-t
     (debian-changelog-setup-highlight-mouse-keymap)
     (debian-changelog-highlight-mouse)))
+  (dpkg-dev-common-utils--add-debputy-settings 'debian-changelog-mode)
   (run-mode-hooks 'debian-changelog-mode-hook))
 ;;(easy-menu-add debian-changelog-menu))
 
