@@ -1,4 +1,4 @@
-;;; debian-control-mode.el --- major mode for Debian control files
+;;; debian-control-mode.el --- major mode for Debian control files -*- lexical-binding: t -*-
 
 ;; Copyright (C) 2001, 2003 Free Software Foundation, Inc.
 ;; Copyright (C) 2003-2005, 2007-2011 Peter S Galbraith <psg@debian.org>
@@ -121,6 +121,7 @@
 
 ;;; Code:
 
+(require 'dpkg-dev-common-utils)
 (require 'easymenu)
 (require 'font-lock)
 (eval-when-compile
@@ -247,6 +248,29 @@
    "\\):")
   "font-lock regexp matching known fields in the binary section.")
 
+(defvar debian-control--email-regexp
+  "<?\\([^<> \t\n]+@[^<> \t\n]+\\.[^<> \t\n]+\\)>?"
+  "font-lock regexp matching an email address.")
+
+(defvar debian-control--supported-url-protocol-prefixes
+  '("file:///"
+    "ftp://"
+    "git://"
+    "http://"
+    "https://"
+    "ssh://"
+    "mailto:")
+  "Supported common protocol prefix in URLs.
+It should be immediately followed by a non-slash character.")
+
+(defvar debian-control--url-regexp
+  (concat
+   "\\("
+   (let ((max-lisp-eval-depth 1000))
+     (regexp-opt debian-control--supported-url-protocol-prefixes nil))
+   "[^/ \t\n][^ \t\n]*\\)")
+  "font-lock regexp matching a URL.")
+
 (defvar debian-control-font-lock-keywords
   `((,(concat "^\\(Source:\\)\\s-*"
               debian-control-package-name-regexp
@@ -263,7 +287,11 @@
     (,debian-control-source-fields-regexp
      (1 font-lock-keyword-face))
     (,debian-control-binary-fields-regexp
-     (1 font-lock-function-name-face))))
+     (1 font-lock-function-name-face))
+    (,debian-control--email-regexp
+     (1 font-lock-variable-name-face))
+    (,debian-control--url-regexp
+     (1 font-lock-constant-face))))
 
 (defvar debian-control-mode-menu nil)
 
@@ -309,7 +337,8 @@
   (if (and (featurep 'goto-addr) goto-address-highlight-p)
       (goto-address))
   (let ((after-change-functions nil))
-    (debian-control-mode-after-change-function (point-min) (point-max) 0)))
+    (debian-control-mode-after-change-function (point-min) (point-max) 0))
+  (dpkg-dev-common-utils--add-debputy-settings 'debian-control-mode))
 
 (defun debian-control-mode-after-change-function (beg end len)
   (save-excursion
